/* 
 * Copyright (c) 2007, Fraunhofer-Gesellschaft
 * All rights reserved.
 * 
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are
 * met:
 * 
 * (1) Redistributions of source code must retain the above copyright
 *     notice, this list of conditions and the disclaimer at the end.
 *     Redistributions in binary form must reproduce the above copyright
 *     notice, this list of conditions and the following disclaimer in
 *     the documentation and/or other materials provided with the
 *     distribution.
 * 
 * (2) Neither the name of Fraunhofer nor the names of its
 *     contributors may be used to endorse or promote products derived
 *     from this software without specific prior written permission.
 * 
 * DISCLAIMER
 * 
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
 * "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
 * LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR
 * A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT
 * OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
 * SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
 * LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE,
 * DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY
 * THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
 * (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
 * OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 *  
 */
package org.ogf.graap.wsag.wsrf;

import org.apache.muse.ws.resource.impl.AbstractWsResourceCapability;
import org.apache.xmlbeans.XmlObject;
import org.ogf.graap.wsag.api.exceptions.WSAgreementException;
import org.w3c.dom.Document;
import org.w3c.dom.Element;
import org.w3c.dom.Node;

/**
 * WSAG4JCapability
 * 
 * Abstract capability that provides some convenience methods.
 * 
 * @author Oliver Waeldrich
 * 
 */
public abstract class WSAG4JCapability extends AbstractWsResourceCapability
{

    /**
     * Converts a XMLBean to a DOM element.
     * 
     * @param xmlObject
     *            the object to convert
     * @return the converted XMLBean
     * 
     * @throws WSAgreementException
     *             indicates a conversion error
     */
    public static Element toElement( XmlObject xmlObject ) throws WSAgreementException
    {
        try
        {

            if ( xmlObject == null )
            {
                return null;
            }

            Node element = xmlObject.getDomNode();
            int nodeType = element.getNodeType();

            if ( nodeType == Node.ELEMENT_NODE )
            {
                return (Element) element;
            }

            if ( nodeType == Node.DOCUMENT_NODE )
            {
                Document document = (Document) element;
                return document.getDocumentElement();
            }

            if ( nodeType == Node.DOCUMENT_FRAGMENT_NODE )
            {
                String message = "Document or element expected, but found xml document fragment.";
                throw new Exception( message );
            }

        }
        catch ( Exception e )
        {
            String message = "Error converting XmlBean to Element. Message: ";
            throw new WSAgreementException( message + e.getMessage() );
        }

        String message =
            "Error converting XmlBean to Element. Node is neither from type document nor element.";
        throw new WSAgreementException( message );
    }

    /**
     * Converts an array of XMLBeans to an array of DOM elements.
     * 
     * @param xmlObjects
     *            the objects to convert
     * @return the element array
     * 
     * @throws WSAgreementException
     *             indicates a conversion error
     */
    public static Element[] toElementArray( XmlObject[] xmlObjects ) throws WSAgreementException
    {
        Element[] elements = new Element[xmlObjects.length];
        for ( int i = 0; i < elements.length; i++ )
        {
            elements[i] = toElement( xmlObjects[i] );
        }

        return elements;
    }
}
