/* 
 * Copyright (c) 2007, Fraunhofer-Gesellschaft
 * All rights reserved.
 * 
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are
 * met:
 * 
 * (1) Redistributions of source code must retain the above copyright
 *     notice, this list of conditions and the disclaimer at the end.
 *     Redistributions in binary form must reproduce the above copyright
 *     notice, this list of conditions and the following disclaimer in
 *     the documentation and/or other materials provided with the
 *     distribution.
 * 
 * (2) Neither the name of Fraunhofer nor the names of its
 *     contributors may be used to endorse or promote products derived
 *     from this software without specific prior written permission.
 * 
 * DISCLAIMER
 * 
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
 * "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
 * LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR
 * A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT
 * OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
 * SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
 * LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE,
 * DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY
 * THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
 * (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
 * OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 *  
 */
package org.ogf.graap.wsag.wsrf;

import org.apache.muse.ws.addressing.EndpointReference;
import org.apache.muse.ws.addressing.soap.SoapFault;
import org.apache.xmlbeans.XmlException;
import org.apache.xmlbeans.XmlObject;
import org.w3.x2005.x08.addressing.EndpointReferenceDocument;
import org.w3.x2005.x08.addressing.EndpointReferenceType;
import org.w3c.dom.Element;

/**
 * XmlUtils
 * 
 * @author Oliver Waeldrich
 * 
 */
public class XmlUtils
{

    /**
     * Converts an {@link EndpointReferenceType} to a MUSE EPR.
     * 
     * @param epr
     *            the EPR to convert
     * 
     * @return the converted EPR
     */
    public static EndpointReference convertEndpointToMuseEPR( EndpointReferenceType epr )
    {
        try
        {
            EndpointReferenceDocument doc = EndpointReferenceDocument.Factory.newInstance();
            doc.setEndpointReference( epr );
            return new EndpointReference( (Element) doc.getDomNode().getFirstChild() );
        }
        catch ( SoapFault e )
        {
            String message = "Error while converting endpoint reference to MUSE EPR.";
            throw new RuntimeException( message, e );
        }
    }

    /**
     * Converts a MUSE EPR to an {@link EndpointReferenceType}.
     * 
     * @param epr
     *            the EPR to convert
     * @return the converted EPR
     */
    public static EndpointReferenceType convertMuseEPRToEndpoint( EndpointReference epr )
    {
        try
        {
            EndpointReferenceDocument converted =
                (EndpointReferenceDocument) XmlObject.Factory.parse( epr.toXML() );
            return converted.getEndpointReference();
        }
        catch ( XmlException e )
        {
            String message = "Error while converting MUSE EPR to endpoint reference.";
            throw new RuntimeException( message, e );
        }
    }
}
