/* 
 * Copyright (c) 2007, Fraunhofer-Gesellschaft
 * All rights reserved.
 * 
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are
 * met:
 * 
 * (1) Redistributions of source code must retain the above copyright
 *     notice, this list of conditions and the disclaimer at the end.
 *     Redistributions in binary form must reproduce the above copyright
 *     notice, this list of conditions and the following disclaimer in
 *     the documentation and/or other materials provided with the
 *     distribution.
 * 
 * (2) Neither the name of Fraunhofer nor the names of its
 *     contributors may be used to endorse or promote products derived
 *     from this software without specific prior written permission.
 * 
 * DISCLAIMER
 * 
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
 * "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
 * LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR
 * A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT
 * OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
 * SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
 * LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE,
 * DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY
 * THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
 * (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
 * OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 *  
 */
package org.ogf.graap.wsag.wsrf.bootstrap;

import org.apache.muse.ws.addressing.MessageHeaders;

/**
 * WSAG4JContextRegistry
 * 
 * @author Oliver Waeldrich
 * 
 */
public class BootstrapRegistry
{

    private static ThreadLocal<MessageHeaders> tlContext = null;

    /**
     * This method cleans up the {@link ThreadLocal} in order to prevent memory leaks. It is invoked by the
     * {@link WSAG4JContextListener} when the web application context is destroyed on server shutdown.
     * 
     * @see WSAG4JContextListener#contextDestroyed(javax.servlet.ServletContextEvent)
     */
    public static synchronized void finalizeBootstrapRegistry()
    {
        //
        // prevent memory leak
        //
        if ( tlContext != null )
        {
            tlContext.set( null );
            tlContext = null;
        }
    }

    private static synchronized ThreadLocal<MessageHeaders> getContext()
    {
        if ( tlContext == null )
        {
            tlContext = new ThreadLocal<MessageHeaders>();
        }
        return tlContext;
    }

    /**
     * Returns the addressing context for the current invocation.
     * 
     * @return the addressing context
     */
    public static MessageHeaders getAddressingContext()
    {
        return getContext().get();
    }

    /**
     * Registers the addressing context for the current invocation.
     * 
     * @param context
     *            the addressing context
     */
    public static void registerAddressingContext( MessageHeaders context )
    {
        getContext().set( context );
    }
}
