/* 
 * Copyright (c) 2007, Fraunhofer-Gesellschaft
 * All rights reserved.
 * 
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are
 * met:
 * 
 * (1) Redistributions of source code must retain the above copyright
 *     notice, this list of conditions and the disclaimer at the end.
 *     Redistributions in binary form must reproduce the above copyright
 *     notice, this list of conditions and the following disclaimer in
 *     the documentation and/or other materials provided with the
 *     distribution.
 * 
 * (2) Neither the name of Fraunhofer nor the names of its
 *     contributors may be used to endorse or promote products derived
 *     from this software without specific prior written permission.
 * 
 * DISCLAIMER
 * 
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
 * "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
 * LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR
 * A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT
 * OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
 * SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
 * LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE,
 * DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY
 * THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
 * (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
 * OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 *  
 */
package org.ogf.graap.wsag.wsrf.bootstrap;

import java.text.MessageFormat;
import java.util.logging.Handler;
import java.util.logging.Level;
import java.util.logging.LogRecord;

import org.apache.log4j.Logger;
import org.apache.log4j.Priority;

/**
 * MuseLog4jHandler
 * 
 * @author Oliver Waeldrich
 * 
 */
public class WSAG4JMuseLog4jHandler extends Handler
{

    private static final int OFF = Level.OFF.intValue();

    private static final int SEVERE = Level.SEVERE.intValue();

    private static final int WARNING = Level.WARNING.intValue();

    private static final int INFO = Level.INFO.intValue();

    private static final int CONFIG = Level.CONFIG.intValue();

    private static final int FINE = Level.FINE.intValue();

    private static final int FINER = Level.FINER.intValue();

    private static final int FINEST = Level.FINEST.intValue();

    private static final int ALL = Level.ALL.intValue();

    /**
     * {@inheritDoc}
     */
    public void publish( LogRecord record )
    {
        org.apache.log4j.Logger log4j = getLog4JLogger( record.getLoggerName() );
        Priority priority = toLog4jLogLevel( record.getLevel() );
        log4j.log( priority, toLog4jMessage( record ), record.getThrown() );
    }

    static Logger getLog4JLogger( String loggerName )
    {
        return Logger.getLogger( loggerName );
    }

    /**
     * Retrieves the Log4J logger for a given class-
     * 
     * @param clazz
     *            the class for which the logger should be retrieved
     * 
     * @return a {@link Logger} instance
     */
    public static Logger getLogger( Class<?> clazz )
    {
        return getLog4JLogger( clazz.getName() );
    }

    private String toLog4jMessage( LogRecord record )
    {
        String message = record.getMessage();

        // Format message
        try
        {
            Object parameters[] = record.getParameters();
            if ( parameters != null && parameters.length != 0 )
            {
                message = MessageFormat.format( message, parameters );
            }
        }
        catch ( Exception ex )
        {
            // ignore Exception
            message = MessageFormat.format( "{0}\n{1}", new Object[] { message, ex.getMessage() } );
        }

        return message;
    }

    private org.apache.log4j.Level toLog4jLogLevel( Level level )
    {

        if ( level.intValue() == ALL )
        {
            return org.apache.log4j.Level.ALL;
        }
        if ( level.intValue() <= FINEST )
        {
            return org.apache.log4j.Level.TRACE;
        }
        if ( level.intValue() <= FINER )
        {
            return org.apache.log4j.Level.TRACE;
        }
        if ( level.intValue() <= FINE )
        {
            return org.apache.log4j.Level.TRACE;
        }
        if ( level.intValue() <= CONFIG )
        {
            return org.apache.log4j.Level.INFO;
        }
        if ( level.intValue() <= INFO )
        {
            return org.apache.log4j.Level.INFO;
        }
        if ( level.intValue() <= WARNING )
        {
            return org.apache.log4j.Level.WARN;
        }
        if ( level.intValue() <= SEVERE )
        {
            return org.apache.log4j.Level.ERROR;
        }
        if ( level.intValue() == OFF )
        {
            return org.apache.log4j.Level.OFF;
        }
        return org.apache.log4j.Level.OFF;
    }

    @Override
    public void flush()
    {
        // nothing to do
    }

    @Override
    public void close()
    {
        // nothing to do
    }

}
