/* 
 * Copyright (c) 2007, Fraunhofer-Gesellschaft
 * All rights reserved.
 * 
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are
 * met:
 * 
 * (1) Redistributions of source code must retain the above copyright
 *     notice, this list of conditions and the disclaimer at the end.
 *     Redistributions in binary form must reproduce the above copyright
 *     notice, this list of conditions and the following disclaimer in
 *     the documentation and/or other materials provided with the
 *     distribution.
 * 
 * (2) Neither the name of Fraunhofer nor the names of its
 *     contributors may be used to endorse or promote products derived
 *     from this software without specific prior written permission.
 * 
 * DISCLAIMER
 * 
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
 * "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
 * LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR
 * A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT
 * OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
 * SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
 * LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE,
 * DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY
 * THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
 * (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
 * OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 *  
 */
package org.ogf.graap.wsag.wsrf.bootstrap;

import java.util.logging.Handler;
import java.util.logging.Level;
import java.util.logging.Logger;

import javax.xml.namespace.QName;

import org.apache.muse.core.Environment;
import org.apache.muse.core.descriptor.DescriptorConstants;
import org.apache.muse.core.descriptor.LoggingConfig;
import org.apache.muse.core.descriptor.SimpleRouterDescriptor;
import org.apache.muse.util.xml.XmlUtils;
import org.w3c.dom.Element;

/**
 * WSAG4JRouterDescriptor
 * 
 * @author Oliver Waeldrich
 * 
 */
public class WSAG4JRouterDescriptor extends SimpleRouterDescriptor
{

    /**
     * Uses log4j as logging framework rather than java logging.
     * 
     * @return the logging configuration
     */
    @Override
    protected LoggingConfig createLoggingConfig()
    {

        LoggingConfig config = new LoggingConfig()
        {

            public Logger newInstance()
            {
                Logger log = Logger.getLogger( MUSE_LOGGER_NAME );
                /*
                 * Level logLevel = getLogLevel(); Handler[] handlers = log.getHandlers(); for (int i = 0; i <
                 * handlers.length; i++) { log.removeHandler(handlers[i]); }
                 */
                log.setUseParentHandlers( false );

                Handler[] handlers = log.getHandlers();
                boolean initialized = false;
                for ( int i = 0; i < handlers.length; i++ )
                {
                    if ( handlers[i] instanceof WSAG4JMuseLog4jHandler )
                    {
                        initialized = true;
                        break;
                    }
                }

                if ( !initialized )
                {
                    log.addHandler( new WSAG4JMuseLog4jHandler() );
                    log.setLevel( getLogLevel() );
                }

                return log;
            }

        };

        return config;
    }

    /*
     * (non-Javadoc)
     * 
     * @see org.apache.muse.core.descriptor.SimpleRouterDescriptor#createLogging(org.w3c.dom.Element,
     * org.apache.muse.core.Environment)
     */
    @Override
    protected LoggingConfig createLogging( Element xml, Environment env )
    {
        QName qname = DescriptorConstants.LOGGING_QNAME;
        Element loggingXML = XmlUtils.getElement( xml, qname );

        LoggingConfig logging = createLoggingConfig();
        Level level = createLogLevel( loggingXML );
        logging.setLogLevel( level );

        return logging;
    }
}
