/* 
 * Copyright (c) 2007, Fraunhofer-Gesellschaft
 * All rights reserved.
 * 
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are
 * met:
 * 
 * (1) Redistributions of source code must retain the above copyright
 *     notice, this list of conditions and the disclaimer at the end.
 *     Redistributions in binary form must reproduce the above copyright
 *     notice, this list of conditions and the following disclaimer in
 *     the documentation and/or other materials provided with the
 *     distribution.
 * 
 * (2) Neither the name of Fraunhofer nor the names of its
 *     contributors may be used to endorse or promote products derived
 *     from this software without specific prior written permission.
 * 
 * DISCLAIMER
 * 
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
 * "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
 * LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR
 * A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT
 * OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
 * SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
 * LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE,
 * DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY
 * THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
 * (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
 * OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 *  
 */
package org.ogf.graap.wsag.wsrf.impl;

import org.apache.log4j.Logger;
import org.apache.muse.core.Resource;
import org.apache.muse.core.ResourceManager;
import org.apache.muse.ws.addressing.soap.SoapFault;
import org.ogf.graap.wsag.server.api.AgreementAcceptanceFactory;
import org.ogf.graap.wsag.server.api.AgreementAcceptanceListener;
import org.ogf.graap.wsag.wsrf.XmlUtils;
import org.w3.x2005.x08.addressing.EndpointReferenceType;

/**
 * Default implementation of an agreement acceptance factory.
 * 
 * @author Oliver Waeldrich
 * 
 */
public class AgreementAcceptanceFactoryImpl implements AgreementAcceptanceFactory
{

    private static final Logger LOG = Logger.getLogger( AgreementAcceptanceFactoryImpl.class );

    private Resource factoryResource;

    /**
     * 
     * @param resource
     *            the web service resource
     */
    public AgreementAcceptanceFactoryImpl( Resource resource )
    {
        factoryResource = resource;
    }

    /**
     * {@inheritDoc}
     */
    public EndpointReferenceType registerAgreementAccetanceListener( AgreementAcceptanceListener handler )
    {
        try
        {
            ResourceManager resourceManager = factoryResource.getResourceManager();

            AgreementAcceptanceWsResource acceptanceResource =
                (AgreementAcceptanceWsResource) resourceManager.createResource( "AgreementAcceptance" );
            acceptanceResource.setAcceptanceHandler( handler );
            resourceManager.addResource( acceptanceResource.getEndpointReference(), acceptanceResource );

            return XmlUtils.convertMuseEPRToEndpoint( acceptanceResource.getEndpointReference() );
        }
        catch ( SoapFault e )
        {
            LOG.error( "Error creating acceptance resource. Cause: " + e.getMessage() );

            if ( LOG.isDebugEnabled() )
            {
                LOG.debug( e );
            }

            throw new IllegalStateException( "Error creating acceptance resource." );
        }
    }

}
