/* 
 * Copyright (c) 2007, Fraunhofer-Gesellschaft
 * All rights reserved.
 * 
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are
 * met:
 * 
 * (1) Redistributions of source code must retain the above copyright
 *     notice, this list of conditions and the disclaimer at the end.
 *     Redistributions in binary form must reproduce the above copyright
 *     notice, this list of conditions and the following disclaimer in
 *     the documentation and/or other materials provided with the
 *     distribution.
 * 
 * (2) Neither the name of Fraunhofer nor the names of its
 *     contributors may be used to endorse or promote products derived
 *     from this software without specific prior written permission.
 * 
 * DISCLAIMER
 * 
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
 * "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
 * LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR
 * A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT
 * OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
 * SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
 * LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE,
 * DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY
 * THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
 * (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
 * OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 *  
 */
package org.ogf.graap.wsag.wsrf.impl;

import javax.xml.namespace.QName;

import org.apache.log4j.Logger;
import org.apache.muse.ws.addressing.soap.SoapFault;
import org.ogf.graap.wsag.api.WsagConstants;
import org.ogf.graap.wsag.server.persistence.PersistentAgreementFactory;
import org.ogf.graap.wsag.wsrf.AbstractWsResource;

/**
 * Default implementation of an agreement factory WSRF resource. Each factory WSRF resource has an agreement
 * factory object associated, which implements the required factory logic.
 * 
 * @see org.ogf.graap.wsag.server.api.IAgreementFactory
 * @see org.ogf.graap.wsag.server.engine.GenericAgreementFactory
 * 
 * @author Oliver Waeldrich
 * 
 */
public class AgreementFactoryWsResource extends AbstractWsResource
{

    private static final Logger LOG = Logger.getLogger( AgreementFactoryWsResource.class );

    private PersistentAgreementFactory impl = null;

    /**
     * {@inheritDoc}
     * 
     * @see AbstractWsResource#getInterfaceName()
     */
    public QName getInterfaceName()
    {
        return WsagConstants.WSAG_AGREEMENT_FACTORY_QNAME;
    }

    /**
     * 
     * @return the agreement factory associated with the factory WSRF resource.
     */
    public PersistentAgreementFactory getAgreementFactory()
    {
        return impl;
    }

    /**
     * Sets the agreement factory for this WSRF resource.
     * 
     * @param factory
     *            the factory to set
     */
    public void setAgreementFactory( PersistentAgreementFactory factory )
    {
        this.impl = factory;
    }

    /**
     * {@inheritDoc}
     */
    public synchronized void shutdown() throws SoapFault
    {
        try
        {
            impl.save();
        }
        catch ( Exception ex )
        {
            String message =
                "An error occured while saving a WSAG4J persistent agreement facotry instance. Error: "
                    + ex.getMessage();
            LOG.error( message );

            throw new SoapFault( message, ex );
        }

        super.shutdown();
    }
}
