/* 
 * Copyright (c) 2005-2011, Fraunhofer-Gesellschaft
 * All rights reserved.
 * 
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are
 * met:
 * 
 * (1) Redistributions of source code must retain the above copyright
 *     notice, this list of conditions and the disclaimer at the end.
 *     Redistributions in binary form must reproduce the above copyright
 *     notice, this list of conditions and the following disclaimer in
 *     the documentation and/or other materials provided with the
 *     distribution.
 * 
 * (2) Neither the name of Fraunhofer nor the names of its
 *     contributors may be used to endorse or promote products derived
 *     from this software without specific prior written permission.
 * 
 * DISCLAIMER
 * 
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
 * "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
 * LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR
 * A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT
 * OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
 * SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
 * LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE,
 * DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY
 * THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
 * (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
 * OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 *  
 */
package org.ogf.graap.wsag.wsrf.impl;

import javax.xml.namespace.QName;

import org.apache.muse.ws.addressing.soap.SoapFault;
import org.apache.xmlbeans.XmlException;
import org.apache.xmlbeans.XmlObject;
import org.w3c.dom.Element;
import org.w3c.dom.Node;

/**
 * Serializer
 * 
 * @author Oliver Waeldrich
 * 
 */
public class Serializer implements org.apache.muse.core.serializer.Serializer
{

    /**
     * De-serializes an object as XML Bean.
     * 
     * @param xml
     *            XML representation of the object
     * 
     * @return the de-serialized document
     * 
     * @throws SoapFault
     *             indicates a de-serialization error
     */
    public Object fromXML( Element xml ) throws SoapFault
    {
        try
        {
            XmlObject result = XmlObject.Factory.parse( xml );
            return result;
        }
        catch ( XmlException e )
        {
            throw new SoapFault( e );
        }
    }

    /**
     * @return the {@link XmlObject} class
     */
    public Class<?> getSerializableType()
    {
        return XmlObject.class;
    }

    /**
     * Serializes an {@link XmlObject} as dom node.
     * 
     * @param obj
     *            the object to serialize
     * @param qname
     *            the document QName
     * @return the serialized document
     * 
     * @throws SoapFault
     *             indicates a serialization error
     */
    public Element toXML( Object obj, QName qname ) throws SoapFault
    {
        Node result = ( (XmlObject) obj ).getDomNode();
        return (Element) result;
    }

}
