/* 
 * Copyright (c) 2007, Fraunhofer-Gesellschaft
 * All rights reserved.
 * 
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are
 * met:
 * 
 * (1) Redistributions of source code must retain the above copyright
 *     notice, this list of conditions and the disclaimer at the end.
 *     Redistributions in binary form must reproduce the above copyright
 *     notice, this list of conditions and the following disclaimer in
 *     the documentation and/or other materials provided with the
 *     distribution.
 * 
 * (2) Neither the name of Fraunhofer nor the names of its
 *     contributors may be used to endorse or promote products derived
 *     from this software without specific prior written permission.
 * 
 * DISCLAIMER
 * 
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
 * "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
 * LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR
 * A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT
 * OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
 * SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
 * LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE,
 * DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY
 * THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
 * (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
 * OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 *  
 */
package org.ogf.graap.wsag.wsrf.sg.impl;

import org.apache.muse.core.Resource;
import org.apache.muse.core.serializer.SerializerRegistry;
import org.apache.muse.ws.addressing.EndpointReference;
import org.apache.muse.ws.addressing.soap.SoapFault;
import org.apache.muse.ws.resource.sg.MembershipContentRule;
import org.ogf.graap.wsag.wsrf.XmlUtils;
import org.ogf.graap.wsag.wsrf.impl.AgreementWsResource;
import org.w3.x2005.x08.addressing.EndpointReferenceType;

/**
 * AgreementFactoryContentRule
 * 
 * @author Oliver Waeldrich
 * 
 */
public class AgreementServiceGroup extends ServiceGroup
{

    /**
     * Extends the basic functionality of a service group. For local resources we set the port type of the
     * resource in the MembershipContentRuleContext. After invocation we remove it from the context.
     * 
     * @param memberEPR
     *            the endpoint reference of the resource to add
     * 
     * @param resource
     *            the resource to add
     * 
     * @throws SoapFault
     *             the resource could not be added
     * 
     * @see org.apache.muse.ws.resource.sg.impl.SimpleServiceGroup#resourceAdded(org.apache.muse.ws.addressing.EndpointReference
     *      , org.apache.muse.core.Resource)
     */
    public void resourceAdded( EndpointReference memberEPR, Resource resource ) throws SoapFault
    {
        try
        {
            EndpointReference museRegistryEPR = getResource().getEndpointReference();
            EndpointReferenceType registryEPR = XmlUtils.convertMuseEPRToEndpoint( museRegistryEPR );

            MembershipContentRuleContext.setRegistryEPR( registryEPR );

            if ( resource instanceof AgreementWsResource )
            {
                EndpointReferenceType factoryEPR = ( (AgreementWsResource) resource ).getFactoryEPR();
                MembershipContentRuleContext.setFactoryEPR( factoryEPR );
            }

            super.resourceAdded( memberEPR, resource );
        }
        finally
        {
            MembershipContentRuleContext.setFactoryEPR( null );
            MembershipContentRuleContext.setRegistryEPR( null );
        }
    }

    /**
     * Initializes the service group.
     * 
     * @throws SoapFault
     *             indicates a initialization error
     * 
     * @see org.apache.muse.ws.resource.sg.impl.SimpleServiceGroup#initialize()
     */
    public void initialize() throws SoapFault
    {
        super.initialize();
        SerializerRegistry registry = SerializerRegistry.getInstance();
        registry.registerSerializer( MembershipContentRule.class,
                                     new AgreementMembershipContentRuleSerializer() );
    }

}
